@@ -17,11 +17,11 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::RIFF;
 
-$VERSION = '1.13';
+$VERSION = '1.15';
 
 sub ProcessMetadata($$$);
 sub ProcessContentDescription($$$);
-sub ProcessPreview($$$);
+sub ProcessPicture($$$);
 sub ProcessCodecList($$$);
 
 # GUID definitions
@@ -277,7 +277,7 @@ my %advancedContentEncryption = (
     Period => {},
     Picture => {
         SubDirectory => {
-            TagTable => 'Image::ExifTool::ASF::Preview',
+            TagTable => 'Image::ExifTool::ASF::Picture',
         },
     },
     PlaylistDelay => {},
@@ -318,40 +318,40 @@ my %advancedContentEncryption = (
     Year => { Groups => { 2 => 'Time' } },
 );
 
-%Image::ExifTool::ASF::Preview = (
-    PROCESS_PROC => \&ProcessPreview,
-    GROUPS => { 2 => 'Video' },
+%Image::ExifTool::ASF::Picture = (
+    PROCESS_PROC => \&ProcessPicture,
+    GROUPS => { 2 => 'Image' },
     0 => {
-        Name => 'PreviewType',
-        PrintConv => {
-            0 => 'Other picture type',
-            1 => '32x32 PNG file icon',
-            2 => 'Other file icon',
-            3 => 'Front album cover',
-            4 => 'Back album cover',
-            5 => 'Leaflet page',
-            6 => 'Media label',
-            7 => 'Lead artist, performer, or soloist',
-            8 => 'Artists or performers',
+        Name => 'PictureType',
+        PrintConv => { # (Note: Duplicated in ID3, ASF and FLAC modules!)
+            0 => 'Other',
+            1 => '32x32 PNG Icon',
+            2 => 'Other Icon',
+            3 => 'Front Cover',
+            4 => 'Back Cover',
+            5 => 'Leaflet',
+            6 => 'Media',
+            7 => 'Lead Artist',
+            8 => 'Artist',
             9 => 'Conductor',
-            10 => 'Band or orchestra',
+            10 => 'Band',
             11 => 'Composer',
-            12 => 'Lyricist or writer',
-            13 => 'Recording studio or location',
-            14 => 'Recording session',
+            12 => 'Lyricist',
+            13 => 'Recording Studio or Location',
+            14 => 'Recording Session',
             15 => 'Performance',
-            16 => 'Capture from movie or video',
-            17 => 'A bright colored fish',
+            16 => 'Capture from Movie or Video',
+            17 => 'Bright(ly) Colored Fish',
             18 => 'Illustration',
-            19 => 'Band or artist logo',
-            20 => 'Publisher or studio logo',
+            19 => 'Band Logo',
+            20 => 'Publisher Logo',
         },
     },
-    1 => 'PreviewMimeType',
-    2 => 'PreviewDescription',
+    1 => 'PictureMimeType',
+    2 => 'PictureDescription',
     3 => {
-        Name => 'PreviewImage',
-        RawConv => '$self->ValidateImage(\$val,$tag)',
+        Name => 'Picture',
+        Binary => 1,
     },
 );
 
@@ -526,7 +526,7 @@ sub ProcessContentDescription($$$)
         my $len = shift @len;
         next unless $len;
         return 0 if $pos + $len > $dirLen;
-        my $val = $exifTool->Unicode2Charset(substr($$dataPt,$pos,$len),'II');
+        my $val = $exifTool->Decode(substr($$dataPt,$pos,$len),'UCS2','II');
         $exifTool->HandleTag($tagTablePtr, $tag, $val);
         $pos += $len;
     }
@@ -571,7 +571,7 @@ sub ReadASF($$$$$)
     my ($exifTool, $dataPt, $pos, $format, $size) = @_;
     my @vals;
     if ($format == 0) { # unicode string
-        $vals[0] = $exifTool->Unicode2Charset(substr($$dataPt,$pos,$size),'II');
+        $vals[0] = $exifTool->Decode(substr($$dataPt,$pos,$size),'UCS2','II');
     } elsif ($format == 2) { # 4-byte boolean
         @vals = ReadValue($dataPt, $pos, 'int32u', undef, $size);
         foreach (@vals) {
@@ -608,7 +608,7 @@ sub ProcessExtendedContentDescription($$$)
         my $nameLen = unpack("x${pos}v", $$dataPt);
         $pos += 2;
         return 0 if $pos + $nameLen + 4 > $dirLen;
-        my $tag = Image::ExifTool::Unicode2Charset(undef,substr($$dataPt,$pos,$nameLen),'II','Latin');
+        my $tag = Image::ExifTool::Decode(undef,substr($$dataPt,$pos,$nameLen),'UCS2','II','Latin');
         $tag =~ s/^WM\///; # remove leading "WM/"
         $pos += $nameLen;
         my ($dType, $dLen) = unpack("x${pos}v2", $$dataPt);
@@ -627,7 +627,7 @@ sub ProcessExtendedContentDescription($$$)
 # Process WM/Picture preview
 # Inputs: 0) ExifTool object reference, 1) dirInfo ref, 2) tag table reference
 # Returns: 1 on success
-sub ProcessPreview($$$)
+sub ProcessPicture($$$)
 {
     my ($exifTool, $dirInfo, $tagTablePtr) = @_;
     my $dataPt = $$dirInfo{DataPt};
@@ -643,8 +643,8 @@ sub ProcessPreview($$$)
     my $str = substr($$dataPt, $dirStart+5, $n);
     if ($str =~ /^((?:..)*?)\0\0((?:..)*?)\0\0/) {
         my ($mime, $desc) = ($1, $2);
-        $exifTool->HandleTag($tagTablePtr, 1, $exifTool->Unicode2Charset($mime,'II'));
-        $exifTool->HandleTag($tagTablePtr, 2, $exifTool->Unicode2Charset($desc,'II')) if length $desc;
+        $exifTool->HandleTag($tagTablePtr, 1, $exifTool->Decode($mime,'UCS2','II'));
+        $exifTool->HandleTag($tagTablePtr, 2, $exifTool->Decode($desc,'UCS2','II')) if length $desc;
     }
     $exifTool->HandleTag($tagTablePtr, 3, substr($$dataPt, $dirStart+5+$n, $picLen));
     return 1;
@@ -672,12 +672,12 @@ sub ProcessCodecList($$$)
         my $nameLen = Get16u($dataPt, $pos + 2) * 2;
         $pos += 4;
         return 0 if $pos + $nameLen + 2 > $dirLen;
-        my $name = $exifTool->Unicode2Charset(substr($$dataPt,$pos,$nameLen),'II');
+        my $name = $exifTool->Decode(substr($$dataPt,$pos,$nameLen),'UCS2','II');
         $exifTool->HandleTag($tagTablePtr, "${type}Name", $name);
         my $descLen = Get16u($dataPt, $pos + $nameLen) * 2;
         $pos += $nameLen + 2;
         return 0 if $pos + $descLen + 2 > $dirLen;
-        my $desc = $exifTool->Unicode2Charset(substr($$dataPt,$pos,$descLen),'II');
+        my $desc = $exifTool->Decode(substr($$dataPt,$pos,$descLen),'UCS2','II');
         $exifTool->HandleTag($tagTablePtr, "${type}Description", $desc);
         my $infoLen = Get16u($dataPt, $pos + $descLen);
         $pos += $descLen + 2 + $infoLen;
@@ -704,7 +704,7 @@ sub ProcessMetadata($$$)
         my ($index, $stream, $nameLen, $dType, $dLen) = unpack("x${pos}v4V", $$dataPt);
         $pos += 12;
         return 0 if $pos + $nameLen + $dLen > $dirLen;
-        my $tag = Image::ExifTool::Unicode2Charset(undef,substr($$dataPt,$pos,$nameLen),'II','Latin');
+        my $tag = Image::ExifTool::Decode(undef,substr($$dataPt,$pos,$nameLen),'UCS2','II','Latin');
         my $val = ReadASF($exifTool,$dataPt,$pos+$nameLen,$dType,$dLen);
         $exifTool->HandleTag($tagTablePtr, $tag, $val,
             DataPt => $dataPt,
@@ -848,7 +848,7 @@ Windows Media Audio (WMA) and Windows Media Video (WMV) files.
 
 =head1 AUTHOR
 
-Copyright 2003-2009, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
