@@ -18,7 +18,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:Public);
 
-$VERSION = '1.15';
+$VERSION = '1.20';
 
 sub SetGeoValues($$;$);
 
@@ -182,7 +182,7 @@ sub LoadTrackLog($$;$)
                         if ($tag) {
                             if ($tag eq 'coords') {
                                 # read KML "Point" coordinates
-                                @$fix{'lat','lon','alt'} = split ',', $1;
+                                @$fix{'lon','lat','alt'} = split ',', $1;
                             } else {
                                 $$fix{$tag} = $1;
                             }
@@ -195,10 +195,17 @@ sub LoadTrackLog($$;$)
                     if ($$fix{lat} and $$fix{lon} and $$fix{'time'} and
                         $$fix{lat} =~ /^[+-]?\d+\.?\d*/ and
                         $$fix{lon} =~ /^[+-]?\d+\.?\d*/ and
-                        $$fix{'time'} =~ /^(\d{4})-(\d+)-(\d+)T(\d+):(\d+):(\d+)(\.\d+)?/)
+                        $$fix{'time'} =~ /^(\d{4})-(\d+)-(\d+)T(\d+):(\d+):(\d+)(\.\d+)?(.*)/)
                     {
                         $time = Time::Local::timegm($6,$5,$4,$3,$2-1,$1-1900);
                         $time += $7 if $7;  # add fractional seconds
+                        my $tz = $8;
+                        # adjust for time zone (otherwise assume UTC)
+                        if ($tz =~ /^([-+])(\d+):(\d{2})\b/) {
+                            $tz = ($2 * 60 + $3) * 60;
+                            $tz *= -1 if $1 eq '+'; # opposite sign to change back to UTC
+                            $time += $tz;
+                        }
                         # validate altitude
                         undef $$fix{alt} if $$fix{alt} and $$fix{alt} !~ /^[+-]?\d+\.?\d*/;
                         $isDate = 1;
@@ -494,7 +501,7 @@ sub ApplySyncCorr($$)
             my ($t0, $t1) = ($$syncTimes[$i0], $$syncTimes[$i1]);
             # interpolate/extrapolate to account for linear camera clock drift
             my $syncPoints = $$sync{Points};
-            my $f = ($time - $t0) / ($t1 - $t0);
+            my $f = $t1 == $t0 ? 0 : ($time - $t0) / ($t1 - $t0);
             $sync = $$syncPoints{$t1} * $f + $$syncPoints{$t0} * (1 - $f);
         } else {
             $sync = $$sync{Offset}; # use fixed time offset
@@ -635,7 +642,7 @@ sub SetGeoValues($$;$)
                     $fix = $$points{$tn};
                 }
             } else {
-                my $f = ($time - $t0) / ($t1 - $t0);
+                my $f = $t1 == $t0 ? 0 : ($time - $t0) / ($t1 - $t0);
                 my $p0 = $$points{$t0};
                 $fix = { };
                 # loop through latitude, longitude, and altitude if available
@@ -718,14 +725,15 @@ sub ConvertGeosync($$)
     my $sync = $exifTool->GetNewValues('Geosync') || { };
     my ($syncFile, $gpsTime, $imgTime);
 
-    if ($val =~ /(.*?)@(.*)/) {
+    if ($val =~ /(.*?)\@(.*)/) {
         $gpsTime = $1;
         if (-f $2) {
             $syncFile = $2;
         } else {
             $imgTime = $2;
         }
-    } else {
+    # (take care because "-f '1:30'" crashes ActivePerl 5.10)
+    } elsif ($val !~ /^\d/ or $val !~ /:/) {
         $syncFile = $val if -f $val;
     }
     if ($gpsTime or defined $syncFile) {
