@@ -15,7 +15,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 sub ProcessMPImageList($$$);
 
@@ -94,7 +94,7 @@ sub ProcessMPImageList($$$);
     NOTES => q{
         The first MPF "Large Thumbnail" image is extracted as PreviewImage, and the
         rest of the embedded MPF images are extracted as MPImage#.  The
-        ExtractEmbedded option may be used to extract information from these
+        ExtractEmbedded (-ee) option may be used to extract information from these
         embedded images.
     },
     0.1 => {
@@ -208,7 +208,12 @@ sub ExtractMPImages($)
                     Groups => { 0 => 'Composite', 1 => 'Composite', 2 => 'Image'},
                 });
             }
-            $exifTool->FoundTag($tag, $val);
+            my $key = $exifTool->FoundTag($tag, $val);
+            # set groups for PreviewImage
+            if ($tag eq 'PreviewImage') {
+                $exifTool->SetGroup($key, 'Composite', 0);
+                $exifTool->SetGroup($key, 'Composite');
+            }
             # extract information from MP images if ExtractEmbedded option used
             if ($ee) {
                 $$exifTool{DOC_NUM} = $i;
