@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.27';
+$VERSION = '1.31';
 
 sub WritePS($$);
 sub ProcessPS($$;$);
@@ -128,6 +128,15 @@ sub AUTOLOAD
     return Image::ExifTool::DoAutoLoad($AUTOLOAD, @_);
 }
 
+#------------------------------------------------------------------------------
+# Is this a PC system
+# Returns: true for PC systems
+my %isPC = (MSWin32 => 1, os2 => 1, dos => 1, NetWare => 1, symbian => 1, cygwin => 1);
+sub IsPC()
+{
+    return $isPC{$^O};
+}
+
 #------------------------------------------------------------------------------
 # Get image width or height
 # Inputs: 0) value list ref (ImageData, BoundingBox), 1) true to get height
@@ -265,6 +274,41 @@ sub DecodeComment($$$;$)
     return $val;
 }
 
+#------------------------------------------------------------------------------
+# Unescape PostScript string
+# Inputs: 0) string
+# Returns: unescaped string
+sub UnescapePostScript($)
+{
+    my $str = shift;
+    # decode escape sequences in literal strings
+    while ($str =~ /\\(.)/sg) {
+        my $n = pos($str) - 2;
+        my $c = $1;
+        my $r;
+        if ($c =~ /[0-7]/) {
+            # get up to 2 more octal digits
+            $c .= $1 if $str =~ /\G([0-7]{1,2})/g;
+            # convert octal escape code
+            $r = chr(oct($c) & 0xff);
+        } elsif ($c eq "\x0d") {
+            # the string is continued if the line ends with '\'
+            # (also remove "\x0d\x0a")
+            $c .= $1 if $str =~ /\G(\x0a)/g;
+            $r = '';
+        } elsif ($c eq "\x0a") {
+            $r = '';
+        } else {
+            # convert escaped characters
+            ($r = $c) =~ tr/nrtbf/\n\r\t\b\f/;
+        }
+        substr($str, $n, length($c)+1) = $r;
+        # continue search after this character
+        pos($str) = $n + length($r);
+    }
+    return $str;
+}
+
 #------------------------------------------------------------------------------
 # Extract information from EPS, PS or AI file
 # Inputs: 0) ExifTool object reference, 1) dirInfo reference, 2) optional tag table ref
@@ -274,7 +318,7 @@ sub ProcessPS($$;$)
     my ($exifTool, $dirInfo, $tagTablePtr) = @_;
     my $raf = $$dirInfo{RAF};
     my $embedded = $exifTool->Options('ExtractEmbedded');
-    my ($data, $dos, $endDoc);
+    my ($data, $dos, $endDoc, $fontTable, $comment);
 
     # allow read from data
     $raf = new File::RandomAccess($$dirInfo{DataPt}) unless $raf;
@@ -283,7 +327,7 @@ sub ProcessPS($$;$)
 #
     $raf->Read($data, 4) == 4 or return 0;
     # accept either ASCII or DOS binary postscript file format
-    return 0 unless $data =~ /^(%!PS|%!Ad|\xc5\xd0\xd3\xc6)/;
+    return 0 unless $data =~ /^(%!PS|%!Ad|%!Fo|\xc5\xd0\xd3\xc6)/;
     if ($data =~ /^%!Ad/) {
         # I've seen PS files start with "%!Adobe-PS"...
         return 0 unless $raf->Read($data, 6) == 6 and $data eq "obe-PS";
@@ -297,6 +341,18 @@ sub ProcessPS($$;$)
         {
             return PSErr($exifTool, 'invalid header');
         }
+    } else {
+        # check for PostScript font file (PFA or PFB)
+        my $d2;
+        $data .= $d2 if $raf->Read($d2,12);
+        if ($data =~ /^%!(PS-(AdobeFont-|Bitstream )|FontType1-)/) {
+            $exifTool->SetFileType('PFA');  # PostScript ASCII font file
+            $fontTable = GetTagTable('Image::ExifTool::Font::PSInfo');
+            # PostScript font files may contain an unformatted comments which may
+            # contain useful information, so accumulate these for the Comment tag
+            $comment = 1;
+        }
+        $raf->Seek(-length($data), 1);
     }
 #
 # set the newline type based on the first newline found in the file
@@ -338,7 +394,7 @@ sub ProcessPS($$;$)
 #
 # parse the postscript
 #
-    my ($buff, $mode, $beginToken, $endToken, $docNum, $subDocNum);
+    my ($buff, $mode, $beginToken, $endToken, $docNum, $subDocNum, $changedNL);
     my (@lines, $altnl);
     if ($/ eq "\x0d") {
         $altnl = "\x0a";
@@ -353,16 +409,31 @@ sub ProcessPS($$;$)
             $raf->ReadLine($data) or last;
             # check for alternate newlines as efficiently as possible
             if ($data =~ /$altnl/) {
-                # split into separate lines
-                @lines = split /$altnl/, $data, -1;
-                $data = shift @lines;
-                if (@lines == 1 and $lines[0] eq $/) {
-                    # handle case of DOS newline data inside file using Unix newlines
-                    $data .= $lines[0];
-                    undef @lines;
+                if (length($data) > 500000 and IsPC()) {
+                    # Windows can't split very long lines due to poor memory handling,
+                    # so re-read the file with the other newline character instead
+                    # (slower but uses less memory)
+                    unless ($changedNL) {
+                        $changedNL = 1;
+                        my $t = $/;
+                        $/ = $altnl;
+                        $altnl = $t;
+                        $raf->Seek(-length($data), 1);
+                        next;
+                    }
+                } else {
+                    # split into separate lines
+                    @lines = split /$altnl/, $data, -1;
+                    $data = shift @lines;
+                    if (@lines == 1 and $lines[0] eq $/) {
+                        # handle case of DOS newline data inside file using Unix newlines
+                        $data .= $lines[0];
+                        undef @lines;
+                    }
                 }
             }
         }
+        undef $changedNL;
         if ($mode) {
             if (not $endToken) {
                 $buff .= $data;
@@ -417,8 +488,7 @@ sub ProcessPS($$;$)
                     $docNum .= '-' . (++$subDocNum);
                 } else {
                     # this is the Nth document
-                    $$exifTool{DOC_COUNT} = ($$exifTool{DOC_COUNT} || 0) + 1;
-                    $docNum = $$exifTool{DOC_COUNT};
+                    $docNum = $$exifTool{DOC_COUNT} + 1;
                 }
                 $subDocNum = 0; # new level, so reset subDocNum
                 next unless $embedded;  # skip over this document
@@ -502,6 +572,32 @@ sub ProcessPS($$;$)
             $val =  # add PS header in case it needs one
             ProcessPS($exifTool, { DataPt => \$val });
             last;
+        } elsif ($fontTable) {
+            if (defined $comment) {
+                # extract initial comments from PostScript Font files
+                if ($data =~ /^%\s+(.*?)[\x0d\x0a]/) {
+                    $comment .= "\n" if $comment;
+                    $comment .= $1;
+                    next;
+                } elsif ($data !~ /^%/) {
+                    # stop extracting comments at the first non-comment line
+                    $exifTool->FoundTag('Comment', $comment) if length $comment;
+                    undef $comment;
+                }
+            }
+            if ($data =~ m{^\s*/(\w+)\s*(.*)} and $$fontTable{$1}) {
+                my ($tag, $val) = ($1, $2);
+                if ($val =~ /^\((.*)\)/) {
+                    $val = UnescapePostScript($1);
+                } elsif ($val =~ m{/?(\S+)}) {
+                    $val = $1;
+                }
+                $exifTool->HandleTag($fontTable, $tag, $val);
+            } elsif ($data =~ /^currentdict end/) {
+                # only extract tags from initial FontInfo dict
+                undef $fontTable;
+            }
+            next;
         } else {
             next;
         }
@@ -554,7 +650,7 @@ This code reads meta information from EPS (Encapsulated PostScript), PS
 
 =head1 AUTHOR
 
-Copyright 2003-2009, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
