@@ -15,7 +15,7 @@ package Image::ExifTool::Shortcuts;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.31';
+$VERSION = '1.35';
 
 # this is a special table used to define command-line shortcuts
 %Image::ExifTool::Shortcuts::Main = (
@@ -179,6 +179,7 @@ $VERSION = '1.31';
         'MakerNoteLeica3',
         'MakerNoteLeica4',
         'MakerNoteLeica5',
+        'MakerNoteLeica6',
         'MakerNotePanasonic',
         'MakerNotePanasonic2',
         'MakerNotePentax',
@@ -187,7 +188,9 @@ $VERSION = '1.31';
         'MakerNotePentax4',
         'MakerNoteRicoh',
         'MakerNoteRicohText',
-        'MakerNoteSamsung',
+        'MakerNoteSamsung1a',
+        'MakerNoteSamsung1b',
+        'MakerNoteSamsung2',
         'MakerNoteSanyo',
         'MakerNoteSanyoC4',
         'MakerNoteSanyoPatch',
@@ -212,6 +215,28 @@ $VERSION = '1.31';
         'InteropIFD:RelatedImageWidth',
         'InteropIFD:RelatedImageHeight',
     ],
+    # common metadata tags found in IFD0 of TIFF images
+    CommonIFD0 => [
+        # standard EXIF
+        'IFD0:ImageDescription',
+        'IFD0:Make',
+        'IFD0:Model',
+        'IFD0:Software',
+        'IFD0:ModifyDate',
+        'IFD0:Artist',
+        'IFD0:Copyright',
+        # other TIFF tags
+        'IFD0:Rating', 
+        'IFD0:RatingPercent',
+        'IFD0:DNGLensInfo',
+        'IFD0:PanasonicTitle',
+        'IFD0:PanasonicTitle2',
+        'IFD0:XPTitle',
+        'IFD0:XPComment',
+        'IFD0:XPAuthor',
+        'IFD0:XPKeywords',
+        'IFD0:XPSubject',
+    ],
 );
 
 #------------------------------------------------------------------------------
@@ -230,10 +255,10 @@ sub LoadShortcuts($)
     }
 }
 # (for backward compatibility, renamed in ExifTool 7.75)
-if (defined %Image::ExifTool::Shortcuts::UserDefined) {
+if (%Image::ExifTool::Shortcuts::UserDefined) {
     LoadShortcuts(\%Image::ExifTool::Shortcuts::UserDefined);
 }
-if (defined %Image::ExifTool::UserDefined::Shortcuts) {
+if (%Image::ExifTool::UserDefined::Shortcuts) {
     LoadShortcuts(\%Image::ExifTool::UserDefined::Shortcuts);
 }
 
