@@ -5,6 +5,7 @@
 #
 # Revisions:    04/06/2004 - P. Harvey Created
 #               02/20/2007 - PH added SD14 tags
+#               24/06/2010 - PH decode some SD15 tags
 #
 # Reference:    http://www.x3f.info/technotes/FileDocs/MakerNoteDoc.html
 #------------------------------------------------------------------------------
@@ -15,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.05';
+$VERSION = '1.08';
 
 %Image::ExifTool::Sigma::Main = (
     WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
@@ -45,17 +46,18 @@ $VERSION = '1.05';
             8 => 'Multi-segment',
         },
     },
-    0x000a => 'Lens',
+    0x000a => 'LensFocalRange',
     0x000b => 'ColorSpace',
+    # SIGMA PhotoPro writes these tags as strings, but some cameras (at least) write them as rational
     0x000c => [
         {
             Name => 'ExposureCompensation',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Expo:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Expo:%+.1f",$val) : undef',
         },
         { #PH
-            Name => 'UnknownCompensation',
+            Name => 'ExposureAdjust',
             Writable => 'rational64s',
             Unknown => 1,
         },
@@ -63,7 +65,7 @@ $VERSION = '1.05';
     0x000d => [
         {
             Name => 'Contrast',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Cont:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Cont:%+.1f",$val) : undef',
         },
@@ -75,7 +77,7 @@ $VERSION = '1.05';
     0x000e => [
         {
             Name => 'Shadow',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Shad:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Shad:%+.1f",$val) : undef',
         },
@@ -87,7 +89,7 @@ $VERSION = '1.05';
     0x000f => [
         {
             Name => 'Highlight',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/High:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("High:%+.1f",$val) : undef',
         },
@@ -99,7 +101,7 @@ $VERSION = '1.05';
     0x0010 => [
         {
             Name => 'Saturation',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Satu:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Satu:%+.1f",$val) : undef',
         },
@@ -111,7 +113,7 @@ $VERSION = '1.05';
     0x0011 => [
         {
             Name => 'Sharpness',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Shar:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Shar:%+.1f",$val) : undef',
         },
@@ -123,7 +125,7 @@ $VERSION = '1.05';
     0x0012 => [
         {
             Name => 'X3FillLight',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/Fill:\s*//, $val',
             ValueConvInv => 'IsFloat($val) ? sprintf("Fill:%+.1f",$val) : undef',
         },
@@ -135,7 +137,7 @@ $VERSION = '1.05';
     0x0014 => [
         {
             Name => 'ColorAdjustment',
-            Condition => '$$self{Model} !~ /SD14$/',
+            Condition => '$format eq "string"',
             ValueConv => '$val =~ s/CC:\s*//, $val',
             ValueConvInv => 'IsInt($val) ? "CC:$val" : undef',
         },
@@ -176,22 +178,43 @@ $VERSION = '1.05';
     },
     0x001d => { #PH
         Name => 'MakerNoteVersion',
-        Format => 'undef',
+        Writable => 'undef',
+    },
+    # 0x001e - int16u: 0, 4, 13 - flash mode?
+    0x001f => { #PH (NC)
+        Name => 'AFPoint',
+        # values: "", "Center", "Center,Center", "Right,Right"
     },
-    # 0x001e - int16u: 0 or 4
-    # 0x001f - string: "" or "Center"
     # 0x0020-21 - string: " "
-    0x0022 => { #PH
-        Name => 'AdjustmentMode',
-        Priority => 0,
-        Unknown => 1,
+    0x0022 => { #PH (NC)
+        Name => 'FileFormat',
+        # values: "JPG", "JPG-S" or "X3F"
     },
-    # 0x0023 - string: "", 10, 131, 150, 152, 169
-    # 0x0024 - string: "" or "Starting calibration file..."
-    # 0x0025 - string: "" or "0.70"
-    # 0x0026-2e - int32u: 0
+    # 0x0023 - string: "", 10, 83, 131, 145, 150, 152, 169
+    0x0024 => 'Calibration',
+    # 0x0025 - string: "", "0.70", "0.90"
+    # 0x0026-2b - int32u: 0
+    0x002c => { #PH
+        Name => 'ColorMode',
+        Writable => 'int32u',
+        PrintConv => {
+            0 => 'n/a',
+            1 => 'Sepia',
+            2 => 'B&W',
+            3 => 'Standard',
+            4 => 'Vivid',
+            5 => 'Neutral',
+            6 => 'Portrait',
+            7 => 'Landscape',
+        },
+    },
+    # 0x002d - int32u: 0
+    # 0x002e - rational64s: (the negative of FlashExposureComp, but why?)
     # 0x002f - int32u: 0, 1
-    0x0030 => 'LensApertureRange', #PH
+    0x0030 => { #PH
+        Name => 'LensApertureRange',
+        Notes => 'changes with focal length. MaxAperture for some models',
+    },
     0x0031 => { #PH
         Name => 'FNumber',
         Writable => 'rational64u',
@@ -202,7 +225,7 @@ $VERSION = '1.05';
         Name => 'ExposureTime',
         Writable => 'rational64u',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
-        PrintConvInv => 'eval $val',
+        PrintConvInv => 'Image::ExifTool::Exif::ConvertFraction($val)',
     },
     0x0033 => { #PH
         Name => 'ExposureTime2',
@@ -210,17 +233,29 @@ $VERSION = '1.05';
         ValueConv => '$val * 1e-6',
         ValueConvInv => 'int($val * 1e6 + 0.5)',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
-        PrintConvInv => 'eval $val',
+        PrintConvInv => 'Image::ExifTool::Exif::ConvertFraction($val)',
     },
-    # 0x0034 - int32u: 0,1,2,3 or 4 (possibly AFPoint?)
+    0x0034 => { #PH
+        Name => 'BurstShot',
+        Writable => 'int32u',
+    },
+    # 0x0034 - int32u: 0,1,2,3 or 4
     0x0035 => { #PH
         Name => 'ExposureCompensation',
         Writable => 'rational64s',
+        # add a '+' sign to positive values
+        PrintConv => '$val and $val =~ s/^(\d)/\+$1/; $val',
+        PrintConvInv => '$val',
     },
     # 0x0036 - string: "                    "
     # 0x0037-38 - string: ""
-    # 0x0039 - string: "", 24, 28, 31, 33, 34
-    0x003a => { #PH (guess!)
+    0x0039 => { #PH
+        Name => 'SensorTemperature',
+        # (string format)
+        PrintConv => 'IsInt($val) ? "$val C" : $val',
+        PrintConvInv => '$val=~s/ ?C$//; $val',
+    },
+    0x003a => { #PH
         Name => 'FlashExposureComp',
         Writable => 'rational64s',
     },
@@ -229,6 +264,10 @@ $VERSION = '1.05';
         Priority => 0,
     },
     0x003c => 'WhiteBalance', #PH
+    0x003d => { #PH (new for SD15)
+        Name => 'PictureMode',
+        Notes => 'same as ColorMode, but "Standard" when ColorMode is Sepia or B&W',
+    },
 );
 
 1;  # end
