@@ -467,10 +467,10 @@ sub WritePS($$)
 
     # set XMP hint flag (1 for adding, 0 for deleting, undef for no change)
     $xmpHint = 1 if $$addDirs{XMP};
-    $xmpHint = 0 if $exifTool->{DEL_GROUP}->{XMP};
+    $xmpHint = 0 if $$exifTool{DEL_GROUP}{XMP};
     $$newTags{XMP_HINT} = $xmpHint if $xmpHint;  # add special tag to newTags list
 
-    my @lines;
+    my (@lines, $changedNL);
     my $altnl = ($/ eq "\x0d") ? "\x0a" : "\x0d";
 
     for (;;) {
@@ -480,8 +480,24 @@ sub WritePS($$)
             $raf->ReadLine($data) or last;
             $dos and CheckPSEnd($raf, $psEnd, $data);
             # split line if it contains other newline sequences
-            SplitLine(\$data, \@lines) if $data =~ /$altnl/;
+            if ($data =~ /$altnl/) {
+                if (length($data) > 500000 and IsPC()) {
+                    # patch for Windows memory problem
+                    unless ($changedNL) {
+                        $changedNL = 1;
+                        my $t = $/;
+                        $/ = $altnl;
+                        $altnl = $t;
+                        $raf->Seek(-length($data), 1);
+                        next;
+                    }
+                } else {
+                    # split into separate lines
+                    SplitLine(\$data, \@lines);
+                }
+            }
         }
+        undef $changedNL;
         if ($endToken) {
             # look for end token
             if ($data =~ m/^$endToken\s*$/is) {
@@ -660,7 +676,8 @@ sub WritePS($$)
         delete $$newTags{XMP_HINT};
         push @notDone, 'PostScript' if %$newTags;
         foreach $dir (qw{Photoshop ICC_Profile XMP}) {
-            push @notDone, $dir if $$editDirs{$dir} and not $doneDir{$dir};
+            push @notDone, $dir if $$editDirs{$dir} and not $doneDir{$dir} and
+                                   not $$exifTool{DEL_GROUP}{$dir};
         }
         @notDone and $exifTool->Warn("Couldn't write ".join('/',@notDone).' information');
     }
