@@ -54,6 +54,12 @@ use Image::ExifTool::XMP;
     },
     beatSpliceParamsRiseInTimeDurationScale => { Writable => 'rational' },
     beatSpliceParamsRiseInTimeDurationValue => { Writable => 'integer' },
+    cameraAngle         => { },
+    cameraLabel         => { },
+    cameraModel         => { },
+    cameraMove          => { },
+    client              => { },
+    comment             => { Name => 'DMComment' },
     composer        => { Groups => { 2 => 'Author' } },
     contributedMedia => {
         SubDirectory => { },
@@ -77,6 +83,8 @@ use Image::ExifTool::XMP;
     contributedMediaManaged      => { List => 1, Writable => 'boolean' },
     contributedMediaWebStatement => { List => 1 },
     copyright       => { Avoid => 1, Groups => { 2 => 'Author' } },
+    director            => { },
+    directorPhotography => { },
     duration        => {
         SubDirectory => { },
         Struct => 'Time',
@@ -86,6 +94,7 @@ use Image::ExifTool::XMP;
     engineer        => { },
     fileDataRate    => { Writable => 'rational' },
     genre           => { },
+    good                => { Writable => 'boolean' },
     instrument      => { },
     introTime => {
         SubDirectory => { },
@@ -126,6 +135,7 @@ use Image::ExifTool::XMP;
     },
     outCueScale         => { Writable => 'rational' },
     outCueValue         => { Writable => 'integer' },
+    projectName         => { },
     projectRef => {
         SubDirectory => { },
         Struct => 'ProjectLink',
@@ -149,8 +159,11 @@ use Image::ExifTool::XMP;
     scaleType           => { },
     scene               => { Avoid => 1 },
     shotDate            => { Groups => { 2 => 'Time' }, %dateTimeInfo },
+    shotDay             => { },
     shotLocation        => { },
     shotName            => { },
+    shotNumber          => { },
+    shotSize            => { },
     speakerPlacement    => { },
     startTimecode => {
         SubDirectory => { },
@@ -160,6 +173,7 @@ use Image::ExifTool::XMP;
     startTimecodeTimeValue  => { },
     startTimecodeValue      => { Writable => 'integer' },
     stretchMode     => { },
+    takeNumber      => { Writable => 'integer' },
     tapeName        => { },
     tempo           => { Writable => 'real' },
     timeScaleParams => {
@@ -188,9 +202,9 @@ use Image::ExifTool::XMP;
         Struct => 'CuePointParam',
         List => 1,
     },
-    TracksMarkersCuePointParamsKey      => { List => 1 },
-    TracksMarkersCuePointParamsValue    => { List => 1 },
-    TracksMarkersCuePointType           => { List => 1 },
+    TracksMarkersCuePointParamsKey  => { List => 1 },
+    TracksMarkersCuePointParamsValue=> { List => 1 },
+    TracksMarkersCuePointType       => { List => 1 },
     TracksMarkersDuration           => { List => 1 },
     TracksMarkersLocation           => { List => 1 },
     TracksMarkersName               => { List => 1 },
@@ -653,11 +667,9 @@ my %plusVocab = (
 %Image::ExifTool::XMP::pur = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-pur', 2 => 'Document' },
-    NAMESPACE => 'prismusagerights',
+    NAMESPACE => 'pur',
     NOTES => q{
-        Prism Usage Rights 2.1 schema tags.  The actual namespace prefix is
-        "prismusagerights", but ExifTool shortens this for the "XMP-pur" family 1
-        group name.  (see L<http://www.prismstandard.org/>)
+        Prism Usage Rights 2.1 schema tags.  (see L<http://www.prismstandard.org/>)
     },
     adultContentWarning => { List => 'Bag' },
     agreement           => { List => 'Bag' },
@@ -683,11 +695,11 @@ my %plusVocab = (
     NAMESPACE => 'DICOM',
     NOTES => 'DICOM schema tags.',
     # change some tag names to correspond with DICOM tags
-    PatientName             => { Name => 'PatientsName' },
+    PatientName             => { },
     PatientID               => { },
-    PatientSex              => { Name => 'PatientsSex' },
+    PatientSex              => { },
     PatientDOB              => {
-        Name => 'PatientsBirthDate',
+        Name => 'PatientBirthDate',
         Groups => { 2 => 'Time' },
         %dateTimeInfo,
     },
@@ -809,12 +821,12 @@ my %plusVocab = (
     ffid        => { Name => 'FFID' },
 );
 
-# IView MediaPro schema properties (mediapro) (ref PH)
+# iView MediaPro schema properties (mediapro) (ref PH)
 %Image::ExifTool::XMP::MediaPro = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-mediapro', 2 => 'Image' },
     NAMESPACE => 'mediapro',
-    NOTES => 'IView MediaPro schema tags.',
+    NOTES => 'iView MediaPro schema tags.',
     Event       => { },
     Location    => {
         Avoid => 1,
@@ -827,6 +839,28 @@ my %plusVocab = (
     CatalogSets => { List => 'Bag' },
 );
 
+# DigiKam schema tags (ref PH)
+%Image::ExifTool::XMP::digiKam = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-digiKam', 2 => 'Image' },
+    NAMESPACE => 'digiKam',
+    NOTES => 'DigiKam schema tags.',
+    CaptionsAuthorNames    => { Writable => 'lang-alt' },
+    CaptionsDateTimeStamps => { Writable => 'lang-alt' },
+    TagsList               => { List => 'Seq' },
+);
+
+# SWF schema tags (ref PH)
+%Image::ExifTool::XMP::swf = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-swf', 2 => 'Image' },
+    NAMESPACE => 'swf',
+    NOTES => 'Adobe SWF schema tags.',
+    type         => { Avoid => 1 },
+    bgalpha      => { Name => 'BackgroundAlpha', Writable => 'integer' },
+    forwardlock  => { Name => 'ForwardLock',     Writable => 'boolean' },
+);
+
 # SVG schema properties (ref 9)
 %Image::ExifTool::XMP::SVG = (
     GROUPS => { 0 => 'SVG', 1 => 'SVG', 2 => 'Image' },
@@ -879,15 +913,11 @@ This module is loaded automatically by Image::ExifTool when required.
 
 =head1 DESCRIPTION
 
-This file contains definitions for the following XMP schemas:
-
-1) PLUS License Data Format 1.2.0
-
-2) Publishing Requirements for Industry Standard Metadata (PRISM) 2.1
+This file contains definitions for less common XMP schemas.
 
 =head1 AUTHOR
 
-Copyright 2003-2009, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
